==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/ronportal/sluzebnicesty/sluzebnicestyutils.php <==
<?php

namespace RonPortal\SluzebniCesty;

use Ron\DB\Database;
use Ron\DB\DBException;
use Ron\MessageManager;
use Ron\StringUtils;
use RonPortal\Log;
use RonPortal\PracovniPomer;
use RonPortal\Prava;
use RonPortal\RonPortalSettings;
use RonPortal\Rozdeleni;
use RonPortal\User;

class SluzebniCestyUtils
{

    static function jePravoNaSlCestuUzivatele($database, $idPP, $datumOd, $datumDo)
    {
        Prava::nastavObdobiProPrava($datumOd, $datumDo);

        $prava = Prava::nactiPravaUzivatele($database, User::getRC(), 'sluzebnicesty');
        if ($prava && $prava->lzeZobrazitPP($idPP)) {
            return true;
        }

        $prava = Prava::nactiPravaUzivatele($database, User::getRC(), 'slcesty_schval1');
        if ($prava && $prava->lzeZobrazitPP($idPP)) {
            return true;
        }

        $prava = Prava::nactiPravaUzivatele($database, User::getRC(), 'slcesty_schval2');
        if ($prava && $prava->lzeZobrazitPP($idPP)) {
            return true;
        }

        $prava = Prava::nactiPravaUzivatele($database, User::getRC(), 'slcesty_schval3');
        if ($prava && $prava->lzeZobrazitPP($idPP)) {
            return true;
        }

        $prava = Prava::nactiPravaUzivatele($database, User::getRC(), 'slcesty_schval4');
        if ($prava && $prava->lzeZobrazitPP($idPP)) {
            return true;
        }

        return false;
    }


    /**
     * @param Database $database
     * @param int $idSluzebniCesty
     * @return null|string
     */
    public static function vratVychoziMenu($database, $idSluzebniCesty)
    {
        $params = $database ->createParameters();

        // podle ciloveho statu
        $sql =
            'SELECT Stat.MenaStatu ' .
            ' FROM SluzebniCesta, Stat ' .
            ' WHERE SluzebniCesta.ID = ' . $params ->addParameter((int)$idSluzebniCesty) .
            '   AND Stat.Kod = SluzebniCesta.CilovyStat ';

        $cursor = $database ->getSqlResult($sql, $params);
        $row = $cursor ->fetch();
        $cursor ->close();
        if ($row) {
            return $row[0];
        }

        // podle cile
        $params = $database ->createParameters();
        $sql =
            'SELECT Stat.MenaStatu ' .
            ' FROM SluzebniCesta, MistoSluzebniCesty, Stat ' .
            ' WHERE SluzebniCesta.ID = ' . $params ->addParameter((int)$idSluzebniCesty) .
            '   AND MistoSluzebniCesty.Kod = SluzebniCesta.Cil ' .
            '   AND Stat.Kod = MistoSluzebniCesty.Stat ';

        $cursor = $database ->getSqlResult($sql, $params);
        $row = $cursor ->fetch();
        $cursor ->close();
        if ($row) {
            return $row[0];
        }

        // prednastavena vychozi mena
        if ( RonPortalSettings::getValue(RonPortalSettings::VYCHOZI_MENA) ) {
            return RonPortalSettings::getValue(RonPortalSettings::VYCHOZI_MENA);
        }

        return '';
    }


    /**
     * Zjisti maximalni denni sazbu stravneho pro dany stat
     * @param Database $database
     * @param int    $datum
     * @param string $cilovyStat
     * @param string $vychoziStat
     * @return bool
     * @throws \Exception
     */
    static function vratMaximalniDenniStravneProStat($database, $datum, $cilovyStat, $vychoziStat)
    {
        // kontrola doplnena kvuli firebirdu - tam to hazelo chybu "Incorrect values within SQLDA structure empty pointer to data at SQLVAR index 1"
        if (!$cilovyStat) {
            throw new \Exception('Chyba pri nacitani maximalniho stravneho - neni zadan cilovy stat!');
        }

        if (!$vychoziStat) {
            throw new \Exception('Chyba pri nacitani maximalniho stravneho - neni zadan vychozi stat!');
        }

        if (!$datum) {
            throw new \Exception('Chyba pri nacitani maximalniho stravneho - neni zadan vychozi datum!');
        }

        $params = $database ->createParameters();
        $sql =
            'SELECT Stat.MenaStatu, Sazba1, Sazba2, Sazba3, Sazba4, Sazba5 ' .
            '  FROM NastaveniVypoctuCN, HistorieNVypoctuCN, Stat ' .
            ' WHERE HistorieNVypoctuCN.Stat = NastaveniVypoctuCN.Stat ' .
            '   AND HistorieNVypoctuCN.PlatnostOd = NastaveniVypoctuCN.PlatnostOd ' .
            '   AND Stat.Kod = NastaveniVypoctuCN.CilovyStat ' .
            '   AND NastaveniVypoctuCN.Stat = ' . $params ->addParameter($vychoziStat) .
            '   AND NastaveniVypoctuCN.CilovyStat = ' . $params ->addParameter($cilovyStat) .
            '   AND NastaveniVypoctuCN.PlatnostOd <= ' . $params ->addParameter($database ->dateToParam($datum)) .
            '   AND (HistorieNVypoctuCN.PlatnostDo >= ' . $params ->addParameter($database ->dateToParam($datum)) . '  OR HistorieNVypoctuCN.PlatnostDo IS NULL) ';

        $cursor = $database ->getSqlResult($sql, $params, 'Pri zjistovani sazby doslo k chybe!');
        $row = $cursor ->fetch();
        $cursor ->close();

        if ( !$row ) {
            throw new \Exception(StringUtils::fromUTF8('Nebyla nalezena sazba stravného pro zadaný cílový stát!'));
        }

        $sazba = (float)$row[1];
        if ((float)$row[2] > $sazba) {
            $sazba = (float)$row[2];
        }
        if ((float)$row[3] > $sazba) {
            $sazba = (float)$row[3];
        }
        if ((float)$row[4] > $sazba) {
            $sazba = (float)$row[4];
        }
        if ((float)$row[5] > $sazba) {
            $sazba = (float)$row[5];
        }

        return [
            'sazba' => $sazba,
            'mena' => $row[0]
        ];
    }



    /**
     * Podle nastaveni portalu a pripadne zadane osoby zjisti vychozi stat
     * @param Database $database
     * @param PracovniPomer $pp
     * @param int      $kDatu
     * @return string|null
     */
    public static function getVychoziStatOsoby($database, $pp, $kDatu)
    {
        if ($typRozdeleni = RonPortalSettings::getIntValue(SluzebniCesta::SETTINGS_TYP_ROZDELENI_PRO_STAT)) {
            $rozdeleni = Rozdeleni::loadRozdeleniOsoby($database, $pp ->idPP, $typRozdeleni, $kDatu);
            if (count($rozdeleni) && $rozdeleni[0] ->stat) {
                return $rozdeleni[0] ->stat;
            }
        }

        return RonPortalSettings::getValue(SluzebniCesta::SETTINGS_STAT) ?: null;
    }


    public static function lzeSchvalitZamestnancem($rc, $idPP, $datumOd, $datumDo)
    {
        Prava::nastavObdobiProPrava($datumOd, $datumDo);
        $pravaSchvaleniZam = Prava::vratPrava('slcesty_zam');

        return $pravaSchvaleniZam ->priznak
            ? $pravaSchvaleniZam ->lzeZobrazitPP($idPP, $datumOd, $datumDo)
            : $rc == User::getRC();
    }

    /**
     * @param Database $database
     * @param int $idOriginal
     * @param int $idNew
     * @param int $dateAdd
     * @throws DBException
     */
    public static function kopirujRadky($database, $idOriginal, $idNew, $dateAdd)
    {
        MessageManager::addDebugMessage('Kopirovani radku SC ... ');

        $params = $database ->createParameters();
        $sql =
            'SELECT CisloRadku, Popis, DatumCasOd, KodOperace, Stat, PocetPJidel_S, PocetPJidel_O, PocetPJidel_V, Misto, Stav' .
            ' FROM RadekSluzebniCesty ' .
            ' WHERE SluzebniCesta_ID = ' . $params ->addParameter($idOriginal);

        try {
            $cursor = $database->select($sql, $params);
        } catch (DBException $e) {
            $errortext = 'Chyba pri kopirovani - nelze nacist radky puvodni sluzebni cesty';
            Log::addRecordToDBLog($database, 'RadekSluzebniCesty', 'ERROR', StringUtils::fromUTF8('Služební cesty'), "$errortext\n{$e ->getMessage()}\n$sql");
            throw $e;
        }

        $logmessage = $sql . "\n";

        while ($row = $cursor ->fetch()) {
            $insertParams = $database ->createParameters();
            $time = $dateAdd + $database ->stringToTimestamp($row[2]);
            $sql =
                'INSERT INTO RadekSluzebniCesty (' .
                ' SluzebniCesta_ID, CisloRadku, Popis, DatumCasOd, KodOperace, Stat, PocetPJidel_S, PocetPJidel_O, PocetPJidel_V, Misto, Stav ' .
                ') VALUES (' .
                $insertParams ->addParameter($idNew) . ', ' . $insertParams ->addParameter($row[0]) . ', ' . // id, cisloRadku
                $insertParams ->addParameter($row[1]) . ', ' . // popis
                $insertParams ->addParameter($database ->timestampToParam($time)) . ', ' . // datumCasOd
                $insertParams ->addParameter($row[3]) . ', ' . // kodOperace
                $insertParams ->addParameter($row[4]) . ', ' . // stat
                $insertParams ->addParameter((int)$row[5]) . ', ' . $insertParams ->addParameter((int)$row[6]) . ', ' . $insertParams ->addParameter((int)$row[7]) . ', ' . // S,O,V
                $insertParams ->addParameter($row[8]) . ', ' . $insertParams ->addParameter((int)$row[9]) . // misto, stav
                ')';

            $logmessage .= $sql."\n";
            $logmessage .=
                $idNew . ', ' . $row[0] . ', ' . (isset($row[1]) ? $row[1] : 'NULL') . ', ' . date('j.n.Y G:i', $time) . ', ' .
                $row[3] . ', ' . (isset($row[4]) ? $row[4] : 'NULL') . ", ...\n";

            try {
                $database->sql($sql, $insertParams);
            } catch (DBException $e) {
                $errortext = 'Chyba pri kopirovani - pri vkladani zaznamu doslo k chybe!';

                Log::addRecordToDBLog($database, 'RadekSluzebniCesty', 'ERROR', StringUtils::fromUTF8('Služební cesty'), "$logmessage$errortext\n{$e ->getMessage()}");

                throw $e;
            }
        }
        $cursor ->close();

        Log::addRecordToDBLog($database, 'RadekSluzebniCesty', 'INSERT', StringUtils::fromUTF8('Služební cesty'), StringUtils::fromUTF8("Kopie služební cesty\n") . $logmessage);
    }


    /**
     * @param Database $database
     * @param int $idOriginal
     * @param int $idNew
     * @param int $dateAdd
     * @throws DBException
     */
    public static function kopirujRadkyUctovani($database, $idOriginal, $idNew, $dateAdd)
    {
        MessageManager::addDebugMessage('Kopirovani uctovani SC ... ');

        $params = $database ->createParameters();
        $sql =
            'SELECT CisloRadku, Typ, Castka, KodMeny, ZpusobPlatby, Den, Popis, NVV_SpotrebaVozidla,' .
            '    NVV_PocetUjetychKM, NVV_NepocitatZaklSazbu, NVV_NeprokazanaCenaPHM, NVV_CenaPHM, NVV_DruhPHM ' .
            '  FROM RadekUctovaniSCesty ' .
            ' WHERE SluzebniCesta_ID = ' . $params ->addParameter((int)$idOriginal) .
            ' AND Typ <> 1  AND Typ <> 2  AND  Typ <> 3 '; // vynecha nahrady a soucty

        $cursor = $database ->select($sql, $params);

        $logMessage = $sql . "\n";

        while ($row = $cursor ->fetch()) {
            $time = $row[5] ? $dateAdd + $database ->stringToTimestamp($row[5]) : null;

            $insertParams = $database ->createParameters();
            $sql =
                'INSERT INTO RadekUctovaniSCesty (' .
                ' SluzebniCesta_ID, CisloRadku, Typ, Castka, KodMeny, ZpusobPlatby, Den, Popis, NVV_SpotrebaVozidla,' .
                '    NVV_PocetUjetychKM, NVV_NepocitatZaklSazbu, NVV_NeprokazanaCenaPHM, NVV_CenaPHM, NVV_DruhPHM ' .
                ') VALUES (' .
                $insertParams ->addParameter($idNew) . ', ' . $insertParams ->addParameter($row[0]) . ', ' .
                $insertParams ->addParameter($row[1]) . ', ' . $insertParams ->addParameter($row[2]) . ', ' .
                $insertParams ->addParameter($row[3]) . ', '. $insertParams ->addParameter($row[4]) . ', ' . // kodMeny, zpusobPlatby
                // den - opravit (nepouzivat cas!)
                $insertParams ->addParameter( $time ? $database ->timestampToParam($time) : null) . ', ' .
                $insertParams ->addParameter($row[6]) . ', ' .
                // NVV
                $insertParams ->addParameter($row[7]) . ', ' . // spotreba
                $insertParams ->addParameter($row[8]) . ', ' . // pocet km
                $insertParams ->addParameter($row[9]) . ', ' . $insertParams ->addParameter($row[10]) . ', ' . // nepocitat z.sazbu, neprokazana cena
                $insertParams ->addParameter($row[11]) . ', ' . // cena PHM
                $insertParams ->addParameter($row[12]) .
                ')';

            $logMessage .= $sql."\n";
            $logMessage .=
                $idNew . ', ' . $row[0] . ', ' . $row[1] . ', ' . $row[2] . ', ' . $row[3] . ', ' . $row[4] . ', ' .
                date('j.n.Y G:i', $time) . ', ' . ($row[6] ?: 'NULL') . ", ...\n";

            try {
                $database ->sql($sql, $insertParams);
            } catch (DBException $e) {
                $errortext = 'Chyba pri kopirovani - pri vkladani zaznamu doslo k chybe!';
                Log::addRecordToDBLog($database, 'RadekUctovaniSCesty', 'ERROR', StringUtils::fromUTF8('Služební cesty'), "$logMessage$errortext\n{$e ->getMessage()}");

                throw $e;
            }
        }
        $cursor ->close();

        Log::addRecordToDBLog($database, 'RadekUctovaniSCesty', 'INSERT', StringUtils::fromUTF8('Služební cesty'), StringUtils::fromUTF8("Kopie služební cesty\n") . $logMessage);
    }

}

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2206_162.zip: ronportal/ronportal/sluzebnicesty/sluzebnicestyutils.php <==
<?php

namespace RonPortal\SluzebniCesty;

use Ron\DB\Database;
use Ron\DB\DBException;
use Ron\MessageManager;
use Ron\StringUtils;
use RonPortal\Log;
use RonPortal\PracovniPomer;
use RonPortal\Prava;
use RonPortal\RonPortalSettings;
use RonPortal\Rozdeleni;
use RonPortal\User;

class SluzebniCestyUtils
{
    /**
     * Zjisti, jestli ma uzivatel prislusne pravo (typ $kodTypuPrava) na sluzebni cestu zadaneho zamestnance ($idPP) v zadanem terminu
     * @param string $kodTypuPrava  Kod typu prava, ktere se ma zkontrolovat
     * @param int   $idPP       Id pracovniho pomeru, kteremu patri SC
     * @param bool  $zahranicni Urcuje, jestli je cesta zahranicni
     * @param int   $datumOd    Pocatek SC
     * @param int   $datumDo    Konec SC
     * @return bool
     * @throws \Exception
     */
    static function jePravoNaSluzebniCestu($kodTypuPrava, $idPP, $zahranicni, $datumOd, $datumDo)
    {
        $prava = Prava::vratPrava($kodTypuPrava, $zahranicni ? $kodTypuPrava . '_Z' : null); // pro zahranicni SC je mozne nadefinovat uzivatelske pravo s priponou _Z
        return $prava ->lzeZobrazitPP($idPP, $datumOd, $datumDo);
    }


    /**
     * Vraci true, pokud muze uzivatel zobrazit sluzebni cestu zadaneho zamestnance ($idPP)
     * @param Database $database
     * @param int   $idPP       Id pracovniho pomeru, kteremu patri SC
     * @param bool  $zahranicni Urcuje, jestli je cesta zahranicni
     * @param int   $datumOd    Pocatek SC
     * @param int   $datumDo    Konec SC
     * @return bool
     * @throws \Exception
     */
    static function jePravoNaSlCestuUzivatele($database, $idPP, $zahranicni, $datumOd, $datumDo)
    {
        Prava::nastavObdobiProPrava($datumOd, $datumDo);
        Prava::nactiPravaUzivatele($database);

        foreach ([
                     'sluzebnicesty', 'slcesty_prohl', 'slcesty_ucet', 'slcesty_nadriz',
                     'slcesty_schval1', 'slcesty_schval2', 'slcesty_schval3', 'slcesty_schval4',
                     'slcesty_zauct'] as $kodPrava) {
            if (self::jePravoNaSluzebniCestu($kodPrava, $idPP, $zahranicni, $datumOd, $datumDo)) {
                return true;
            }
        }

        return false;
    }


    /**
     * Vraci seznam typu uctovani SC, ktere jsou NVV (kody oddelene strednikem)
     * @param Database $database
     * @return string
     */
    public static function typyUctovaniNVV($database)
    {
        $sql =
            'SELECT Kod, DruhPohybu, NahradaZaVlastniVozidlo FROM TypRUctovaniSlCesty' .
            ' WHERE Aktivni = 1 AND NahradaZaVlastniVozidlo = 1';

        $cursor = $database ->select($sql);
        $result = '';

        while ($row = $cursor ->fetch()) {
            $result .= ($result ? ';' : '') . $row[0];
        }

        $cursor ->close();

        return $result;
    }


    /**
     * @param Database $database
     * @param int $idSluzebniCesty
     * @return null|string
     */
    public static function vratVychoziMenu($database, $idSluzebniCesty)
    {
        $params = $database ->createParameters();

        // podle ciloveho statu
        $sql =
            'SELECT Stat.MenaStatu ' .
            ' FROM SluzebniCesta, Stat ' .
            ' WHERE SluzebniCesta.ID = ' . $params ->addParameter((int)$idSluzebniCesty) .
            '   AND Stat.Kod = SluzebniCesta.CilovyStat ';

        $cursor = $database ->getSqlResult($sql, $params);
        $row = $cursor ->fetch();
        $cursor ->close();
        if ($row) {
            return $row[0];
        }

        // podle cile
        $params = $database ->createParameters();
        $sql =
            'SELECT Stat.MenaStatu ' .
            ' FROM SluzebniCesta, MistoSluzebniCesty, Stat ' .
            ' WHERE SluzebniCesta.ID = ' . $params ->addParameter((int)$idSluzebniCesty) .
            '   AND MistoSluzebniCesty.Kod = SluzebniCesta.Cil ' .
            '   AND Stat.Kod = MistoSluzebniCesty.Stat ';

        $cursor = $database ->getSqlResult($sql, $params);
        $row = $cursor ->fetch();
        $cursor ->close();
        if ($row) {
            return $row[0];
        }

        // prednastavena vychozi mena
        if ( RonPortalSettings::getValue(RonPortalSettings::VYCHOZI_MENA) ) {
            return RonPortalSettings::getValue(RonPortalSettings::VYCHOZI_MENA);
        }

        return '';
    }


    /**
     * Zjisti maximalni denni sazbu stravneho pro dany stat
     * @param Database $database
     * @param int    $datum
     * @param string $cilovyStat
     * @param string $vychoziStat
     * @return bool
     * @throws \Exception
     */
    static function vratMaximalniDenniStravneProStat($database, $datum, $cilovyStat, $vychoziStat)
    {
        // kontrola doplnena kvuli firebirdu - tam to hazelo chybu "Incorrect values within SQLDA structure empty pointer to data at SQLVAR index 1"
        if (!$cilovyStat) {
            throw new \Exception('Chyba pri nacitani maximalniho stravneho - neni zadan cilovy stat!');
        }

        if (!$vychoziStat) {
            throw new \Exception('Chyba pri nacitani maximalniho stravneho - neni zadan vychozi stat!');
        }

        if (!$datum) {
            throw new \Exception('Chyba pri nacitani maximalniho stravneho - neni zadan vychozi datum!');
        }

        $params = $database ->createParameters();
        $sql =
            'SELECT Stat.MenaStatu, Sazba1, Sazba2, Sazba3, Sazba4, Sazba5 ' .
            '  FROM NastaveniVypoctuCN, HistorieNVypoctuCN, Stat ' .
            ' WHERE HistorieNVypoctuCN.Stat = NastaveniVypoctuCN.Stat ' .
            '   AND HistorieNVypoctuCN.PlatnostOd = NastaveniVypoctuCN.PlatnostOd ' .
            '   AND Stat.Kod = NastaveniVypoctuCN.CilovyStat ' .
            '   AND NastaveniVypoctuCN.Stat = ' . $params ->addParameter($vychoziStat) .
            '   AND NastaveniVypoctuCN.CilovyStat = ' . $params ->addParameter($cilovyStat) .
            '   AND NastaveniVypoctuCN.PlatnostOd <= ' . $params ->addParameter($database ->dateToParam($datum)) .
            '   AND (HistorieNVypoctuCN.PlatnostDo >= ' . $params ->addParameter($database ->dateToParam($datum)) . '  OR HistorieNVypoctuCN.PlatnostDo IS NULL) ';

        $cursor = $database ->getSqlResult($sql, $params, 'Pri zjistovani sazby doslo k chybe!');
        $row = $cursor ->fetch();
        $cursor ->close();

        if ( !$row ) {
            throw new \Exception(StringUtils::fromUTF8('Nebyla nalezena sazba stravného pro zadaný cílový stát!'));
        }

        $sazba = (float)$row[1];
        if ((float)$row[2] > $sazba) {
            $sazba = (float)$row[2];
        }
        if ((float)$row[3] > $sazba) {
            $sazba = (float)$row[3];
        }
        if ((float)$row[4] > $sazba) {
            $sazba = (float)$row[4];
        }
        if ((float)$row[5] > $sazba) {
            $sazba = (float)$row[5];
        }

        return [
            'sazba' => $sazba,
            'mena' => $row[0]
        ];
    }



    /**
     * Podle nastaveni portalu a pripadne zadane osoby zjisti vychozi stat
     * @param Database $database
     * @param PracovniPomer $pp
     * @param int      $kDatu
     * @return string|null
     */
    public static function getVychoziStatOsoby($database, $pp, $kDatu)
    {
        if ($typRozdeleni = RonPortalSettings::getIntValue(SluzebniCesta::SETTINGS_TYP_ROZDELENI_PRO_STAT)) {
            $rozdeleni = Rozdeleni::loadRozdeleniOsoby($database, $pp ->idPP, $typRozdeleni, $kDatu);
            if (count($rozdeleni) && $rozdeleni[0] ->stat) {
                return $rozdeleni[0] ->stat;
            }
        }

        return RonPortalSettings::getValue(SluzebniCesta::SETTINGS_STAT) ?: null;
    }


    public static function lzeSchvalitZamestnancem($rc, $idPP, $zahranicni, $datumOd, $datumDo)
    {
        Prava::nastavObdobiProPrava($datumOd, $datumDo);
        $pravaSchvaleniZam = Prava::vratPrava('slcesty_zam', $zahranicni ? 'slcesty_zam_Z' : null);

        return $pravaSchvaleniZam ->priznak
            ? $pravaSchvaleniZam ->lzeZobrazitPP($idPP, $datumOd, $datumDo)
            : $rc == User::getRC();
    }

    /**
     * @param Database $database
     * @param int $idOriginal
     * @param int $idNew
     * @param int $dateAdd
     * @throws DBException
     */
    public static function kopirujRadky($database, $idOriginal, $idNew, $dateAdd)
    {
        MessageManager::addDebugMessage('Kopirovani radku SC ... ');

        $params = $database ->createParameters();
        $sql =
            'SELECT CisloRadku, Popis, DatumCasOd, KodOperace, Stat, PocetPJidel_S, PocetPJidel_O, PocetPJidel_V, Misto, Stav' .
            ' FROM RadekSluzebniCesty ' .
            ' WHERE SluzebniCesta_ID = ' . $params ->addParameter($idOriginal);

        try {
            $cursor = $database->select($sql, $params);
        } catch (DBException $e) {
            $errortext = 'Chyba pri kopirovani - nelze nacist radky puvodni sluzebni cesty';
            Log::addRecordToDBLog($database, 'RadekSluzebniCesty', 'ERROR', StringUtils::fromUTF8('Služební cesty'), "$errortext\n{$e ->getMessage()}\n$sql");
            throw $e;
        }

        $logmessage = $sql . "\n";

        while ($row = $cursor ->fetch()) {
            $insertParams = $database ->createParameters();
            $time = $dateAdd + $database ->stringToTimestamp($row[2]);
            $sql =
                'INSERT INTO RadekSluzebniCesty (' .
                ' SluzebniCesta_ID, CisloRadku, Popis, DatumCasOd, KodOperace, Stat, PocetPJidel_S, PocetPJidel_O, PocetPJidel_V, Misto, Stav ' .
                ') VALUES (' .
                $insertParams ->addParameter($idNew) . ', ' . $insertParams ->addParameter($row[0]) . ', ' . // id, cisloRadku
                $insertParams ->addParameter($row[1]) . ', ' . // popis
                $insertParams ->addParameter($database ->timestampToParam($time)) . ', ' . // datumCasOd
                $insertParams ->addParameter($row[3]) . ', ' . // kodOperace
                $insertParams ->addParameter($row[4]) . ', ' . // stat
                $insertParams ->addParameter((int)$row[5]) . ', ' . $insertParams ->addParameter((int)$row[6]) . ', ' . $insertParams ->addParameter((int)$row[7]) . ', ' . // S,O,V
                $insertParams ->addParameter($row[8]) . ', ' . $insertParams ->addParameter((int)$row[9]) . // misto, stav
                ')';

            $logmessage .= $sql."\n";
            $logmessage .=
                $idNew . ', ' . $row[0] . ', ' . (isset($row[1]) ? $row[1] : 'NULL') . ', ' . date('j.n.Y G:i', $time) . ', ' .
                $row[3] . ', ' . (isset($row[4]) ? $row[4] : 'NULL') . ", ...\n";

            try {
                $database->sql($sql, $insertParams);
            } catch (DBException $e) {
                $errortext = 'Chyba pri kopirovani - pri vkladani zaznamu doslo k chybe!';

                Log::addRecordToDBLog($database, 'RadekSluzebniCesty', 'ERROR', StringUtils::fromUTF8('Služební cesty'), "$logmessage$errortext\n{$e ->getMessage()}");

                throw $e;
            }
        }
        $cursor ->close();

        Log::addRecordToDBLog($database, 'RadekSluzebniCesty', 'INSERT', StringUtils::fromUTF8('Služební cesty'), StringUtils::fromUTF8("Kopie služební cesty\n") . $logmessage);
    }


    /**
     * @param Database $database
     * @param int $idOriginal
     * @param int $idNew
     * @param int $dateAdd
     * @throws DBException
     */
    public static function kopirujRadkyUctovani($database, $idOriginal, $idNew, $dateAdd)
    {
        MessageManager::addDebugMessage('Kopirovani uctovani SC ... ');

        $params = $database ->createParameters();
        $sql =
            'SELECT CisloRadku, Typ, Castka, KodMeny, ZpusobPlatby, Den, Popis, NVV_SpotrebaVozidla,' .
            '    NVV_PocetUjetychKM, NVV_NepocitatZaklSazbu, NVV_NeprokazanaCenaPHM, NVV_CenaPHM, NVV_DruhPHM ' .
            '  FROM RadekUctovaniSCesty ' .
            ' WHERE SluzebniCesta_ID = ' . $params ->addParameter((int)$idOriginal) .
            ' AND Typ <> 1  AND Typ <> 2  AND  Typ <> 3 '; // vynecha nahrady a soucty

        $cursor = $database ->select($sql, $params);

        $logMessage = $sql . "\n";

        while ($row = $cursor ->fetch()) {
            $time = $row[5] ? $dateAdd + $database ->stringToTimestamp($row[5]) : null;

            $insertParams = $database ->createParameters();
            $sql =
                'INSERT INTO RadekUctovaniSCesty (' .
                ' SluzebniCesta_ID, CisloRadku, Typ, Castka, KodMeny, ZpusobPlatby, Den, Popis, NVV_SpotrebaVozidla,' .
                '    NVV_PocetUjetychKM, NVV_NepocitatZaklSazbu, NVV_NeprokazanaCenaPHM, NVV_CenaPHM, NVV_DruhPHM ' .
                ') VALUES (' .
                $insertParams ->addParameter($idNew) . ', ' . $insertParams ->addParameter($row[0]) . ', ' .
                $insertParams ->addParameter($row[1]) . ', ' . $insertParams ->addParameter($row[2]) . ', ' .
                $insertParams ->addParameter($row[3]) . ', '. $insertParams ->addParameter($row[4]) . ', ' . // kodMeny, zpusobPlatby
                // den - opravit (nepouzivat cas!)
                $insertParams ->addParameter( $time ? $database ->timestampToParam($time) : null) . ', ' .
                $insertParams ->addParameter($row[6]) . ', ' .
                // NVV
                $insertParams ->addParameter($row[7]) . ', ' . // spotreba
                $insertParams ->addParameter($row[8]) . ', ' . // pocet km
                $insertParams ->addParameter($row[9]) . ', ' . $insertParams ->addParameter($row[10]) . ', ' . // nepocitat z.sazbu, neprokazana cena
                $insertParams ->addParameter($row[11]) . ', ' . // cena PHM
                $insertParams ->addParameter($row[12]) .
                ')';

            $logMessage .= $sql."\n";
            $logMessage .=
                $idNew . ', ' . $row[0] . ', ' . $row[1] . ', ' . $row[2] . ', ' . $row[3] . ', ' . $row[4] . ', ' .
                date('j.n.Y G:i', $time) . ', ' . ($row[6] ?: 'NULL') . ", ...\n";

            try {
                $database ->sql($sql, $insertParams);
            } catch (DBException $e) {
                $errortext = 'Chyba pri kopirovani - pri vkladani zaznamu doslo k chybe!';
                Log::addRecordToDBLog($database, 'RadekUctovaniSCesty', 'ERROR', StringUtils::fromUTF8('Služební cesty'), "$logMessage$errortext\n{$e ->getMessage()}");

                throw $e;
            }
        }
        $cursor ->close();

        Log::addRecordToDBLog($database, 'RadekUctovaniSCesty', 'INSERT', StringUtils::fromUTF8('Služební cesty'), StringUtils::fromUTF8("Kopie služební cesty\n") . $logMessage);
    }

}
